@@ -1,8 +1,7 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { expect } from '@playwright/test';
-import { JupyterLabPage, test } from '@jupyterlab/galata';
+import { expect, JupyterLabPage, test } from '@jupyterlab/galata';
 
 test.describe('page', () => {
   test('should return a JupyterLabPage', ({ page }) => {
@@ -122,7 +121,7 @@ test.describe('sessions', () => {
     await page.menu.clickMenuItem('File>New>Console');
     await page.waitForSelector('.jp-Dialog');
     await page.click('.jp-Dialog .jp-mod-accept');
-    await page.waitForSelector('text=Idle');
+    await page.waitForSelector('text= | Idle');
 
     expect(sessions.size).toEqual(2);
   });
