@@ -1,8 +1,7 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { galata, test } from '@jupyterlab/galata';
-import { expect } from '@playwright/test';
+import { expect, galata, test } from '@jupyterlab/galata';
 import * as path from 'path';
 
 const fileName = 'toc_notebook.ipynb';
@@ -10,8 +9,8 @@ const fileName = 'toc_notebook.ipynb';
 test.use({ tmpPath: 'test-toc' });
 
 test.describe.serial('Table of Contents', () => {
-  test.beforeAll(async ({ baseURL, tmpPath }) => {
-    const contents = galata.newContentsHelper(baseURL);
+  test.beforeAll(async ({ baseURL, request, tmpPath }) => {
+    const contents = galata.newContentsHelper(baseURL, undefined, request);
     await contents.uploadFile(
       path.resolve(__dirname, `./notebooks/${fileName}`),
       `${tmpPath}/${fileName}`
@@ -31,8 +30,8 @@ test.describe.serial('Table of Contents', () => {
     await page.notebook.close(true);
   });
 
-  test.afterAll(async ({ baseURL, tmpPath }) => {
-    const contents = galata.newContentsHelper(baseURL);
+  test.afterAll(async ({ baseURL, request, tmpPath }) => {
+    const contents = galata.newContentsHelper(baseURL, undefined, request);
     await contents.deleteDirectory(tmpPath);
   });
 
@@ -213,4 +212,22 @@ test.describe.serial('Table of Contents', () => {
     expect(await tocPanel.screenshot()).toMatchSnapshot(imageName);
     await tags[1].click();
   });
+
+  test('Open context menu', async ({ page }) => {
+    await page.notebook.selectCells(0);
+    await page.sidebar.openTab('table-of-contents');
+
+    const tocPanel = await page.sidebar.getContentPanel(
+      await page.sidebar.getTabPosition('table-of-contents')
+    );
+
+    await (await tocPanel.$('li > .toc-level-size-1')).click({
+      button: 'right'
+    });
+
+    const menu = await page.menu.getOpenMenu();
+    expect(await menu.screenshot()).toMatchSnapshot(
+      'notebook-context-menu.png'
+    );
+  });
 });
